cctp
=======

简介
------

用于快速搭建 `Python` 项目的 `Cookiecutter <https://www.cookiecutter.io/>`_ 模板.

主要特性:

- 支持 ``Python >= 3.9`` 环境
- 支持 ``uv`` 构建项目
- 支持 ``sphinx`` 文档构建工具
- 支持 ``alabaster`` / ``sphinx_rtd_theme`` / ``classic`` 等多种文档风格
- 支持 ``Typer`` / ``Argparse`` 命令行项目

快速开始
----------

使用 ``cctp`` 创建 `Python` 项目模板 ::

    $ uvx cctp

也可使用以下方式: ::

    $ uvx cookiecutter https://gitee.com/gooker_young/cctp.git
